@@ -136,7 +136,7 @@ class StandardTrainer:
           );
 
           # Logs the result
-          prediction_result = self.model.predict(X_test)
+          prediction_result = self.model.predict(self.X_test)
           mae = metrics.mean_absolute_error(self.y_test, prediction_result)
           rms = mean_squared_error(self.y_test, prediction_result, squared=False)
           mse = mean_squared_error(self.y_test, prediction_result)
